aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJacob Rideout <kde@jacobrideout.net>2007-01-22 16:11:47 +0000
committerJacob Rideout <kde@jacobrideout.net>2007-01-22 16:11:47 +0000
commit28b830b8cd8f3af771620fd627ed6c952331767f (patch)
tree22e1860066b7ade200d061ddbdd7db174ff36ae4
parentaf2b8b438d0ae57f744c1b49a92237b8a5ddc4cd (diff)
downloadextra-cmake-modules-28b830b8cd8f3af771620fd627ed6c952331767f.tar.gz
extra-cmake-modules-28b830b8cd8f3af771620fd627ed6c952331767f.tar.bz2
Changed kspell2 to sonnet where relevant, in anticipation of merging sonnet-refactoring into trunk
svn path=/trunk/KDE/kdelibs/; revision=626251
-rw-r--r--modules/FindENCHANT.cmake4
-rw-r--r--modules/FindKDE4Internal.cmake17
2 files changed, 14 insertions, 7 deletions
diff --git a/modules/FindENCHANT.cmake b/modules/FindENCHANT.cmake
index f7a3f0f6..1a12fe6b 100644
--- a/modules/FindENCHANT.cmake
+++ b/modules/FindENCHANT.cmake
@@ -27,10 +27,12 @@ IF (NOT WIN32)
set(ENCHANT_DEFINITIONS ${_ENCHANTCflags})
ENDIF (NOT WIN32)
- FIND_PATH(ENCHANT_INCLUDE_DIR enchant/enchant.h
+ FIND_PATH(ENCHANT_INCLUDE_DIR enchant++.h
${_ENCHANTIncDir}
/usr/include
+ /usr/include/enchant
/usr/local/include
+ /usr/local/include/enchant
)
FIND_LIBRARY(ENCHANT_LIBRARIES NAMES enchant
diff --git a/modules/FindKDE4Internal.cmake b/modules/FindKDE4Internal.cmake
index f2577f89..82abcd1f 100644
--- a/modules/FindKDE4Internal.cmake
+++ b/modules/FindKDE4Internal.cmake
@@ -33,7 +33,8 @@
# KDE4_KJS_LIBRARY - the kjs library
# KDE4_KNEWSTUFF_LIBRARY - the knewstuff library
# KDE4_KDEPRINT_LIBRARY - the kdeprint library
-# KDE4_KSPELL2_LIBRARY - the kspell2 library
+# KDE4_SONNETCORE_LIBRARY - the sonnetcore library
+# KDE4_SONNETUI_LIBRARY - the sonnetui library
# KDE4_KDNSSD_LIBRARY - the kdnssd library
# KDE4_PHONONCORE_LIBRARY - the phononcore library
# KDE4_PHONONUI_LIBRARY - the phononui library
@@ -43,8 +44,8 @@
# KDE4_SOLID_LIBRARY - the solid library
# KDE4_SOLIDIFACES_LIBRARY - the solidiface library
# KDE4_KNOTIFYCONFIG_LIBRARY- the knotifyconfig library
-# KDE4_KROSSCORE_LIBRARY- the krosscore library
-# KDE4_KTEXTEDITOR_LIBRARY - the ktexteditor library
+# KDE4_KROSSCORE_LIBRARY - the krosscore library
+# KDE4_KTEXTEDITOR_LIBRARY - the ktexteditor library
# KDE4_KWALLETCLIENT_LIBRARY - the kwalletclient library
#
# Compared to the variables above, the following variables
@@ -62,7 +63,8 @@
# KDE4_KJS_LIBS - the kjs library and all depending libraries
# KDE4_KNEWSTUFF_LIBS - the knewstuff library and all depending libraries
# KDE4_KDEPRINT_LIBS - the kdeprint library and all depending libraries
# KDE4_KSPELL2_LIBS - the kspell2 library and all depending libraries
# KDE4_KDNSSD_LIBS - the kdnssd library and all depending libraries
# KDE4_KDESU_LIBS - the kdesu library and all depending libraries
# KDE4_PHONONCORE_LIBS - the phononcore library and all depending librairies
@@ -425,8 +427,11 @@ else(EXISTS ${CMAKE_SOURCE_DIR}/kdecore/kernel/kglobal.h)
find_library(KDE4_KDEPRINT_LIBRARY NAMES kdeprint PATHS ${KDE4_LIB_INSTALL_DIR} NO_DEFAULT_PATH )
set(KDE4_KDEPRINT_LIBS ${kdeprint_LIB_DEPENDS} ${KDE4_KDEPRINT_LIBRARY} )
- find_library(KDE4_KSPELL2_LIBRARY NAMES kspell2 PATHS ${KDE4_LIB_INSTALL_DIR} NO_DEFAULT_PATH )
- set(KDE4_KSPELL2_LIBS ${kspell2_LIB_DEPENDS} ${KDE4_KSPELL2_LIBRARY} )
+ find_library(KDE4_SONNETCORE_LIBRARY NAMES sonnetcore PATHS ${KDE4_LIB_INSTALL_DIR} NO_DEFAULT_PATH )
+ set(KDE4_SONNETCORE_LIBS ${sonnetcore_LIB_DEPENDS} ${KDE4_SONNETCORE_LIBRARY} )
+
+ find_library(KDE4_SONNETUI_LIBRARY NAMES sonnetui PATHS ${KDE4_LIB_INSTALL_DIR} NO_DEFAULT_PATH )
+ set(KDE4_SONNETUI_LIBS ${sonnetui_LIB_DEPENDS} ${KDE4_SONNETUI_LIBRARY} )
if (UNIX)
find_library(KDE4_KDESU_LIBRARY NAMES kdesu PATHS ${KDE4_LIB_INSTALL_DIR} NO_DEFAULT_PATH )
@@ -62,7 +63,8 @@
# KDE4_KNEWSTUFF_LIBS - the knewstuff library and all depending libraries
# KDE4_KDEPRINT_LIBS - the kdeprint library and all depending libraries
-# KDE4_KSPELL2_LIBS - the kspell2 library and all depending libraries
+# KDE4_SONNETCORE_LIBS - the sonnetcore library and all depending libraries
+# KDE4_SONNETUI_LIBS - the sonnetui library and all depending libraries
# KDE4_KDNSSD_LIBS - the kdnssd library and all depending libraries
# KDE4_KDESU_LIBS - the kdesu library and all depending libraries